@@ -1,7 +1,7 @@
 /*
  * dfu-programmer
  *
- * $Id: arguments.c 149 2013-02-21 22:54:47Z slarge $
+ * $Id: arguments.c 164 2013-07-18 22:49:56Z slarge $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -312,7 +312,6 @@ static int32_t assign_option( int32_t *arg,
     return -1;
 }
 
-
 static int32_t assign_target( struct programmer_arguments *args,
                               char *value,
                               struct target_mapping_structure *map )
@@ -329,7 +328,7 @@ static int32_t assign_target( struct programmer_arguments *args,
             args->device_address = 0;
             if (value[name_len] == ':') {
               /* The target name includes USB bus and address info.
-               * This is used to differentiate between multiple dfu 
+               * This is used to differentiate between multiple dfu
                * devices with the same vendor/chip ID numbers. By
                * specifying the bus and address, mltiple units can
                * be programmed at one time.
@@ -348,7 +347,14 @@ static int32_t assign_target( struct programmer_arguments *args,
             args->flash_page_size = map->flash_page_size;
             args->eeprom_page_size = map->eeprom_page_size;
             args->initial_abort = map->initial_abort;
-            args->honor_interfaceclass = map->honor_interfaceclass;
+            /* There have been several reports on the mailing list of dfu-programmer
+               reporting "No device present" when there clearly is. It seems Atmel's
+               bootloader has changed (or is buggy) and doesn't report interface class
+               and subclass the way is did before. However we have already matched
+               VID and PID so why would we worry about this. Don't use the device-
+               specific value, just ignore the error for all device types.
+            */
+            args->honor_interfaceclass = false;
             args->memory_address_top = map->memory_size - 1;
             args->memory_address_bottom = 0;
             args->flash_address_top = args->memory_address_top;
@@ -392,7 +398,6 @@ static int32_t assign_target( struct programmer_arguments *args,
     return -1;
 }
 
-
 static int32_t assign_global_options( struct programmer_arguments *args,
                                       const size_t argc,
                                       char **argv )
@@ -563,8 +568,6 @@ static int32_t assign_com_setfuse_option( struct programmer_arguments *args,
     return 0;
 }
 
-
-
 static int32_t assign_com_configure_option( struct programmer_arguments *args,
                                             const int32_t parameter,
                                             char *value )
@@ -593,7 +596,6 @@ static int32_t assign_com_configure_option( struct programmer_arguments *args,
     return 0;
 }
 
-
 static int32_t assign_com_flash_option( struct programmer_arguments *args,
                                         const int32_t parameter,
                                         char *value )
@@ -619,8 +621,6 @@ static int32_t assign_com_getfuse_option( struct programmer_arguments *args,
     return 0;
 }
 
-
-
 static int32_t assign_com_get_option( struct programmer_arguments *args,
                                       const int32_t parameter,
                                       char *value )
@@ -635,7 +635,6 @@ static int32_t assign_com_get_option( struct programmer_arguments *args,
     return 0;
 }
 
-
 static int32_t assign_command_options( struct programmer_arguments *args,
                                        const size_t argc,
                                        char **argv )
@@ -695,7 +694,6 @@ static int32_t assign_command_options( struct programmer_arguments *args,
     return 0;
 }
 
-
 static void print_args( struct programmer_arguments *args )
 {
     const char *command = "(unknown)";
@@ -756,7 +754,6 @@ static void print_args( struct programmer_arguments *args )
     fflush( stdout );
 }
 
-
 int32_t parse_arguments( struct programmer_arguments *args,
                          const size_t argc,
                          char **argv )
